@@ -77,7 +77,9 @@ class HttpClient(object):
 
         cmd_url = "{endpoint}{cmd}?".format(endpoint=self.endpoint,
                                             cmd=rest_command)
-        log.debug("Request is: %s", cmd_url)
+        # To be revisited - cmd_url contains credentials if Basic Auth
+        # is embedded in the URL
+        # log.debug("Request is: %s", cmd_url)
 
         try:
             if file is not None:
@@ -89,8 +91,6 @@ class HttpClient(object):
                                                          headers=headers,
                                                          cert=self.cert)
             else:
-                print(cmd_url)
-                print(parameters)
                 response = self._tls_session.request(http_method, cmd_url,
                                                      params=parameters,
                                                      timeout=utils.TIMEOUT,
