@@ -1,6 +1,7 @@
 from nose.tools import (
     assert_raises,
     assert_is_none,
+    assert_equal
     )
 
 try:
@@ -17,6 +18,7 @@ from python_kemptech_api.utils import (
     validate_port,
     validate_ip,
     validate_protocol,
+    falsey_to_none
     )
 from python_kemptech_api.exceptions import (
     ValidationError
@@ -63,3 +65,10 @@ class Test_validate_protocol:
     def test_invalid(self):
         with assert_raises(ValidationError):
             validate_protocol('sds')
+
+
+def test_falsey_to_none():
+    expected = None
+    var = 0
+    actual = falsey_to_none(var)
+    assert_equal(expected, actual)
